%global __provides_exclude_from ^(%{python2_sitearch}|%{python3_sitearch})/.*\\.so$

%global module blosc

# Use the same directory of the main package for subpackage licence and docs
%global _docdir_fmt %{name}

Summary:        Python wrapper for the Blosc high performance compressor
Name:           python-%{module}
Version:        1.2.8
Release:        5%{?dist}
License:        MIT
URL:            https://github.com/FrancescAlted/python-blosc
Source0:        https://pypi.python.org/packages/source/b/%{module}/%{module}-%{version}.tar.gz
Patch0:         0001-tests-fix-error-with-new-numpy.patch

BuildRequires:  blosc-devel
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  numpy
BuildRequires:  python2-psutil

%description
%{summary}.

%package -n python2-%{module}
Summary:        %{summary}

%{?python_provide:%python_provide python2-blosc}
%{?fedora:Recommends: numpy}

%description -n python2-%{module}
%{summary}.

%package -n python%{python3_pkgversion}-%{module}
Summary:        Python wrapper for the blosc high performance compressor

BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-numpy
BuildRequires:  python%{python3_pkgversion}-psutil
%{?python_provide:%python_provide python%{python3_pkgversion}-blosc}
%{?fedora:Recommends: python%{python3_pkgversion}-numpy}

%description -n python%{python3_pkgversion}-%{module}
%{summary}.

%if 0%{?python3_other_pkgversion}
%package -n python%{python3_other_pkgversion}-%{module}
Summary:        Python wrapper for the blosc high performance compressor

BuildRequires:  python%{python3_other_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-setuptools
BuildRequires:  python%{python3_other_pkgversion}-numpy
BuildRequires:  python%{python3_other_pkgversion}-psutil
%{?python_provide:%python_provide python%{python3_other_pkgversion}-blosc}
%{?fedora:Recommends: python%{python3_other_pkgversion}-numpy}

%description -n python%{python3_other_pkgversion}-%{module}
%{summary}.
%endif

%prep
%autosetup -n %{module}-%{version} -p1

# Don't enable SSE2 optimizations
sed -i "s|CFLAGS\.append(\"-msse2\")|pass|" setup.py

%build
export BLOSC_DIR=%{_libdir}/blosc CFLAGS="%{optflags}"
%py2_build
%py3_build
%if 0%{?python3_other_pkgversion}
%py3_other_build
%endif

%install
%py2_install
%py3_install
%if 0%{?python3_other_pkgversion}
%py3_other_install
%endif

%check
cd / # avoid interference with build dir
PYTHONPATH=%{buildroot}%{python2_sitearch} %{__python2} -c 'import sys, blosc; sys.exit(blosc.test())'
PYTHONPATH=%{buildroot}%{python3_sitearch} %{__python3} -c 'import sys, blosc; sys.exit(blosc.test())'
%if 0%{?python3_other_pkgversion}
PYTHONPATH=%{buildroot}%{python3_other_sitearch} %{__python3_other} -c 'import sys, blosc; sys.exit(blosc.test())'
%endif

%files -n python2-%{module}
%{python2_sitearch}/blosc/
%{python2_sitearch}/blosc-%{version}*-py*.egg-info
%license LICENSES/PYTHON-BLOSC.txt
%doc README.rst RELEASE_NOTES.rst

%files -n python%{python3_pkgversion}-%{module}
%{python3_sitearch}/blosc/
%{python3_sitearch}/blosc-%{version}*-py*.egg-info
%license LICENSES/PYTHON-BLOSC.txt
%doc README.rst RELEASE_NOTES.rst

%if 0%{?python3_other_pkgversion}
%files -n python%{python3_other_pkgversion}-%{module}
%{python3_other_sitearch}/blosc/
%{python3_other_sitearch}/blosc-%{version}*-py*.egg-info
%license LICENSES/PYTHON-BLOSC.txt
%doc README.rst RELEASE_NOTES.rst
%endif

%changelog
* Thu Mar 07 2019 Troy Dawson <tdawson@redhat.com> - 1.2.8-5
- Rebuilt to change main python from 3.4 to 3.6

* Mon Nov 12 2018 Orion Poplawski <orion@cora.nwra.com> - 1.2.8-4
- Build for python36

* Mon May 16 2016 Orion Poplawski <orion@cora.nwra.com> - 1.2.8-3
- Fix provides filter
- Use %%python3_pkgversion for EPEL7 compatibility

* Sat Feb 13 2016 Zbigniew Jędrzejewski-Szmek <zbyszek@bupkis> - 1.2.8-2
- Add dependency on psutil to check for leaks during build
- Fix build (#1307896)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 16 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.8-1
- Update to latest version (#1263680)
- Add python2 subpackage following the latest guidelines

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.7-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri May 29 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.7-3
- Run test suite

* Thu May 28 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.7-2
- Build python 3 subpackage
- Install license and readme files

* Thu May  7 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.7-1
- Update to 1.2.7 (#1212231)

* Mon Apr 20 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.5-1
- Update to 1.2.5 (#1212231)

* Tue Jan 06 2015 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.4-1
- Update to 1.2.4

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Mar 26 2014 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.2.3-2
- Rebuild for blosc

* Sat Mar 22 2014 Thibault North <tnorth@fedoraproject.org> - 1.2.3-1
- Update to 1.2.3 for blosc 1.3.4

* Wed Jan 08 2014 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.1-8
- Rebuild for blosc

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-7
- Properly link with blosc shared lib

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-6
- Disable SSE2 optimizations

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-5
- Final cosmetic fixes

* Tue Nov 05 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-4
- Fix wrong lib perms

* Fri Oct 18 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-3
- Fixes, thanks to Christopher Meng

* Wed Oct 16 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-2
- Various fixes

* Fri Sep 20 2013 Thibault North <tnorth@fedoraproject.org> - 1.1-1
- Sync to version 1.1

* Mon Jan 2 2012 Thibault North <tnorth@fedoraproject.org> - 1.0.7-1
- Initial package
